#!/usr/bin/env python
import click

from cli.commands.init import init
from cli.commands.login import login
from cli.commands.logout import logout
from cli.commands.vault_cmd import vault
from cli.commands.list_cmd import list_cmd
from cli.commands.push import push
from cli.commands.pull import pull
from cli.commands.sync import sync
from cli.commands.status import status
from cli.commands.search import search
from cli.commands.diff import diff


@click.group()
@click.version_option(prog_name="deeply-env")
def cli():
    """Deeply CLI - 환경 변수 관리 도구

    dotenv-vault와 유사하게 로컬 .env 파일을 관리하고 서버와 동기화합니다.
    """
    pass


# 명령어 등록
cli.add_command(init)
cli.add_command(login)
cli.add_command(logout)
cli.add_command(vault)
cli.add_command(list_cmd)
cli.add_command(push)
cli.add_command(pull)
cli.add_command(sync)
cli.add_command(status)
cli.add_command(search)
cli.add_command(diff)


if __name__ == "__main__":
    cli()



import click
import requests
from rich.console import Console
from rich.table import Table

from cli.utils.config import get_api_client
from cli.utils.token import get_token


@click.command()
def status():
    """서버 상태 확인

    서버 연결 상태, 버전 정보, 로그인 상태, 현재 선택된 볼트 정보를 표시합니다.
    """
    try:
        console = Console()
        table = Table(title="Deeply Vault 상태")
        table.add_column("항목", style="cyan")
        table.add_column("상태", style="green")

        # API 클라이언트 설정
        try:
            api_client = get_api_client()
            server_url = api_client["server"]
            vault_name = api_client["vault"]
            token = get_token()

            # 서버 상태 확인
            response = requests.get(f"{server_url}/api/health_check")

            print(response.json())

            if response.status_code == 200:
                server_status = "연결됨"
                version = response.json().get("version", "알 수 없음")
            else:
                server_status = "연결 실패"
                version = "알 수 없음"

            # 로그인 상태
            login_status = "로그인됨" if token else "로그아웃됨"

            # 정보 표시
            table.add_row("서버 상태", server_status)
            table.add_row("서버 버전", version)
            table.add_row("로그인 상태", login_status)
            table.add_row("현재 볼트", vault_name)

        except Exception:
            table.add_row("서버 상태", "연결 실패")
            table.add_row("서버 버전", "알 수 없음")
            table.add_row("로그인 상태", "로그아웃됨")
            table.add_row("현재 볼트", "선택되지 않음")

        console.print(table)

    except Exception as e:
        click.echo(f"오류가 발생했습니다: {str(e)}", err=True)



import click
import requests

from cli.utils.config import get_config, save_config
from cli.utils.token import save_token


@click.command()
@click.option("--server", "-s", help="서버 URL")
def login(server):
    """서버에 로그인

    API 인증 토큰을 발급받고 저장합니다.
    """
    try:
        # 설정 파일 읽기
        config = get_config()

        if server:
            config["server"] = server

        server_url = config.get("server")

        if not server_url:
            click.echo(
                "서버 URL이 설정되지 않았습니다. 명령어 예시: deeply login -s http://localhost:13500")
            return

        # 사용자 인증
        username = click.prompt("사용자명")
        password = click.prompt("비밀번호", hide_input=True)

        # 토큰 발급 요청
        response = requests.post(
            f"{server_url}/api/v1/auth/token",
            data={"username": username, "password": password}
        )

        if response.status_code != 200:
            click.echo(
                f"로그인 실패: {response.json().get('detail', '알 수 없는 오류')}", err=True)
            return

        # 토큰 저장
        token_data = response.json()
        token = token_data.get("access_token")
        save_token(token)

        # 설정 파일 업데이트 (토큰 제외)
        save_config(config)

        click.echo("Vault 로그인 성공! API 토큰이 ~/.deeply/vault/token.json에 저장되었습니다.")

    except Exception as e:
        click.echo(f"오류가 발생했습니다: {str(e)}", err=True)



import json
from pathlib import Path


def get_token_path():
    """토큰 파일의 경로를 반환합니다."""
    return Path.home() / ".deeply" / "vault" / "token.json"


def save_token(token: str):
    """토큰을 파일에 저장합니다."""
    token_path = get_token_path()
    token_path.parent.mkdir(parents=True, exist_ok=True)

    with open(token_path, 'w') as f:
        json.dump({"token": token}, f)


def get_token() -> str:
    """저장된 토큰을 반환합니다."""
    token_path = get_token_path()
    if token_path.exists():
        with open(token_path, 'r') as f:
            data = json.load(f)
            return data.get("token", "")
    return ""


def delete_token():
    """저장된 토큰을 삭제합니다."""
    token_path = get_token_path()
    if token_path.exists():
        token_path.unlink()
        return True

    return False



import click
import requests
import yaml
from urllib.parse import quote

from cli.utils.config import get_config, get_api_client


@click.command()
@click.argument("vault_name")
@click.option("--description", "-d", help="볼트 설명")
@click.option("--kms-key-id", help="AWS KMS 키 ID")
def new(vault_name, description, kms_key_id):
    """새 볼트 생성 또는 기존 볼트 덮어쓰기

    새로운 환경 변수 볼트를 생성하거나 기존 볼트를 덮어씁니다.
    """
    try:
        api_client = get_api_client()
        server_url = api_client["server"]
        token = api_client["token"]

        headers = {
            "Authorization": f"Bearer {token}",
            "Content-Type": "application/json"
        }

        # KMS 키 ID 입력
        if not kms_key_id:
            kms_key_id = click.prompt("AWS KMS 키 ID를 입력하세요", type=str)

        # 기존 볼트 확인
        response = requests.get(
            f"{server_url}/api/v1/vaults",
            headers=headers
        )

        if response.status_code != 200:
            click.echo(
                f"볼트 목록 조회 실패: {response.json().get('detail', '알 수 없는 오류')}", err=True)
            return

        # 볼트 목록에서 이름으로 검색
        vaults = response.json().get('items', [])

        existing_vault = next(
            (v for v in vaults if v.get('name') == vault_name), None)

        if existing_vault:
            # 기존 볼트가 있으면 덮어쓰기
            vault_id = existing_vault.get('_id')
            encoded_vault_id = quote(vault_id, safe='')

            response = requests.patch(
                f"{server_url}/api/v1/vaults/{encoded_vault_id}",
                headers=headers,
                json={
                    "kms_key_id": kms_key_id,
                    "description": description or existing_vault.get('description', '')
                }
            )
            if response.status_code >= 200 and response.status_code < 300:
                click.echo(f"✓ '{vault_name}' 볼트가 업데이트되었습니다.")
            else:
                click.echo(
                    f"✗ 볼트 업데이트 실패: {response.json().get('detail', '알 수 없는 오류')}", err=True)
                return
        else:
            # 새 볼트 생성
            response = requests.post(
                f"{server_url}/api/v1/vaults",
                headers=headers,
                json={
                    "name": vault_name,
                    "kms_key_id": kms_key_id,
                    "description": description or ""
                }
            )
            if response.status_code >= 200 and response.status_code < 300:
                click.echo(f"✓ '{vault_name}' 볼트가 생성되었습니다.")
            else:
                click.echo(
                    f"✗ 볼트 생성 실패: {response.json().get('detail', '알 수 없는 오류')}", err=True)
                return

        # 설정 파일 업데이트
        config = get_config()
        config["vault"] = vault_name

        with open(".env.vault.yml", "w") as f:
            yaml.dump(config, f, sort_keys=False, indent=2, allow_unicode=True)

        click.echo(f"현재 프로젝트의 볼트가 '{vault_name}'(으)로 설정되었습니다.")

    except Exception as e:
        click.echo(f"오류가 발생했습니다: {str(e)}", err=True)



import click
import os
import yaml
from pathlib import Path


@click.command()
@click.option("--vault", "-v", help="볼트 이름")
@click.option("--force", "-f", is_flag=True, help="기존 설정 덮어쓰기")
def init(vault, force):
    """프로젝트 초기화

    현재 디렉토리에 .env.vault.yml 설정 파일을 생성하고 프로젝트를 초기화합니다.
    """
    config_file = Path(".env.vault.yml")

    if config_file.exists() and not force:
        click.echo("이미 초기화된 프로젝트입니다. 덮어쓰려면 --force 옵션을 사용하세요.")
        return

    if not vault:
        vault = click.prompt(
            "볼트 이름을 입력하세요", default=os.path.basename(os.getcwd()))

    config = {
        "vault": vault,
        "server": "http://localhost:13500",  # 기본 서버 주소
    }

    with open(config_file, "w") as f:
        yaml.dump(config, f, sort_keys=False, indent=2, allow_unicode=True)

    click.echo(f"프로젝트가 초기화되었습니다. 볼트: {vault}")
    click.echo("다음 명령어로 로그인하세요: uvx deeply-vault login")
